@@ -22,8 +22,6 @@
 #include "config.h"
 
 #include "gcr-dbus-constants.h"
-#define DEBUG_FLAG GCR_DEBUG_PROMPT
-#include "gcr-debug.h"
 #include "gcr-internal.h"
 #include "gcr-library.h"
 #include "gcr-prompt.h"
@@ -315,7 +313,7 @@ gcr_system_prompter_dispose (GObject *obj)
 {
 	GcrSystemPrompter *self = GCR_SYSTEM_PROMPTER (obj);
 
-	_gcr_debug ("disposing prompter");
+	g_debug ("disposing prompter");
 
 	if (self->pv->prompter_registered)
 		gcr_system_prompter_unregister (self, FALSE);
@@ -332,7 +330,7 @@ gcr_system_prompter_finalize (GObject *obj)
 {
 	GcrSystemPrompter *self = GCR_SYSTEM_PROMPTER (obj);
 
-	_gcr_debug ("finalizing prompter");
+	g_debug ("finalizing prompter");
 
 	g_assert (self->pv->connection == NULL);
 	g_assert (self->pv->prompter_registered == 0);
@@ -348,7 +346,7 @@ gcr_system_prompter_new_prompt (GcrSystemPrompter *self)
 {
 	g_return_val_if_fail (self->pv->prompt_type != 0, NULL);
 
-	_gcr_debug ("creating new %s prompt", g_type_name (self->pv->prompt_type));
+	g_debug ("creating new %s prompt", g_type_name (self->pv->prompt_type));
 
 	return g_object_new (self->pv->prompt_type, NULL);
 }
@@ -494,14 +492,14 @@ prompt_stop_prompting (GcrSystemPrompter *self,
 	GVariant *retval;
 	gpointer watch;
 
-	_gcr_debug ("stopping prompting for operation %s@%s",
-	            callback->path, callback->name);
+	g_debug ("stopping prompting for operation %s@%s",
+	         callback->path, callback->name);
 
 	/* Get a pointer to our actual callback */
 	if (!g_hash_table_lookup_extended (self->pv->callbacks, callback,
 	                                   (gpointer *)&callback, &watch)) {
-		_gcr_debug ("couldn't find the callback for prompting operation %s@%s",
-		            callback->path, callback->name);
+		g_debug ("couldn't find the callback for prompting operation %s@%s",
+		         callback->path, callback->name);
 		return;
 	}
 
@@ -523,12 +521,12 @@ prompt_stop_prompting (GcrSystemPrompter *self,
 		g_hash_table_remove (self->pv->active, callback);
 
 		if (!active->ready) {
-			_gcr_debug ("cancelling active prompting operation for %s@%s",
-			            callback->path, callback->name);
+			g_debug ("cancelling active prompting operation for %s@%s",
+			         callback->path, callback->name);
 			g_cancellable_cancel (active->cancellable);
 		}
 
-		_gcr_debug ("closing the prompt");
+		g_debug ("closing the prompt");
 		gcr_prompt_close (active->prompt);
 		g_object_run_dispose (G_OBJECT (active->prompt));
 		active_prompt_unref (active);
@@ -536,8 +534,8 @@ prompt_stop_prompting (GcrSystemPrompter *self,
 
 	/* Notify the caller */
 	if (send_done_message && wait_for_reply) {
-		_gcr_debug ("calling the %s on %s@%s, and waiting for reply",
-		            GCR_DBUS_CALLBACK_METHOD_DONE, callback->path, callback->name);
+		g_debug ("calling the %s method on %s@%s, and waiting for reply",
+		         GCR_DBUS_CALLBACK_METHOD_DONE, callback->path, callback->name);
 
 		retval = g_dbus_connection_call_sync (self->pv->connection,
 		                                      callback->name,
@@ -551,12 +549,12 @@ prompt_stop_prompting (GcrSystemPrompter *self,
 		if (retval)
 			g_variant_unref (retval);
 
-		_gcr_debug ("returned from %s on %s@%s",
-		            GCR_DBUS_CALLBACK_METHOD_DONE, callback->path, callback->name);
+		g_debug ("returned from %s on %s@%s",
+		         GCR_DBUS_CALLBACK_METHOD_DONE, callback->path, callback->name);
 
 	} else if (send_done_message) {
-		_gcr_debug ("calling the %s on %s@%s, and ignoring reply",
-		            GCR_DBUS_CALLBACK_METHOD_DONE, callback->path, callback->name);
+		g_debug ("calling the %s method on %s@%s, and ignoring reply",
+		         GCR_DBUS_CALLBACK_METHOD_DONE, callback->path, callback->name);
 
 		g_dbus_connection_call (self->pv->connection,
 		                        callback->name,
@@ -592,8 +590,8 @@ on_prompt_ready_complete (GObject *source,
 
 	g_assert (active->ready == FALSE);
 
-	_gcr_debug ("returned from the %s method on %s@%s",
-	            GCR_DBUS_CALLBACK_METHOD_READY, active->callback->path, active->callback->name);
+	g_debug ("returned from the %s method on %s@%s",
+	         GCR_DBUS_CALLBACK_METHOD_READY, active->callback->path, active->callback->name);
 
 	active->ready = TRUE;
 	retval = g_dbus_connection_call_finish (G_DBUS_CONNECTION (source), result, &error);
@@ -606,8 +604,8 @@ on_prompt_ready_complete (GObject *source,
 	/* The ready call failed,  */
 	} else if (error != NULL) {
 		if (g_error_matches (error, G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_METHOD))
-			_gcr_debug ("prompt %s@%s disappeared or does not exist",
-			            active->callback->path, active->callback->name);
+			g_debug ("prompt %s@%s disappeared or does not exist",
+			         active->callback->path, active->callback->name);
 		else
 			g_message ("received an error from the prompt callback: %s", error->message);
 		g_error_free (error);
@@ -648,8 +646,8 @@ prompt_send_ready (ActivePrompt *active,
 	self = active->prompter;
 	builder = prompt_build_properties (active->prompt, active->changed);
 
-	_gcr_debug ("calling the %s method on %s@%s",
-	            GCR_DBUS_CALLBACK_METHOD_READY, active->callback->path, active->callback->name);
+	g_debug ("calling the %s method on %s@%s",
+	         GCR_DBUS_CALLBACK_METHOD_READY, active->callback->path, active->callback->name);
 
 	g_dbus_connection_call (self->pv->connection,
 	                        active->callback->name,
@@ -681,8 +679,8 @@ prompt_next_ready (GcrSystemPrompter *self)
 	if (callback == NULL)
 		return;
 
-	_gcr_debug ("preparing a prompt for callback %s@%s",
-	            callback->path, callback->name);
+	g_debug ("preparing a prompt for callback %s@%s",
+	         callback->path, callback->name);
 
 	active = g_hash_table_lookup (self->pv->active, callback);
 	g_assert (active == NULL);
@@ -754,8 +752,8 @@ on_caller_vanished (GDBusConnection *connection,
 	}
 
 	while ((callback = g_queue_pop_head (&queue)) != NULL) {
-		_gcr_debug ("caller vanished for callback %s@%s",
-		            callback->path, callback->name);
+		g_debug ("caller vanished for callback %s@%s",
+		         callback->path, callback->name);
 		prompt_stop_prompting (self, callback, FALSE, FALSE);
 	}
 }
@@ -773,13 +771,13 @@ prompter_method_begin_prompting (GcrSystemPrompter *self,
 	lookup.name = caller = g_dbus_method_invocation_get_sender (invocation);
 	g_variant_get (parameters, "(&o)", &lookup.path);
 
-	_gcr_debug ("received %s call from callback %s@%s",
-	            GCR_DBUS_PROMPTER_METHOD_BEGIN,
-	            lookup.path, lookup.name);
+	g_debug ("received %s call from callback %s@%s",
+	         GCR_DBUS_PROMPTER_METHOD_BEGIN,
+	         lookup.path, lookup.name);
 
 	if (g_hash_table_lookup (self->pv->callbacks, &lookup)) {
-		_gcr_debug ("already begun prompting for callback %s@%s",
-		            lookup.path, lookup.name);
+		g_debug ("already begun prompting for callback %s@%s",
+		         lookup.path, lookup.name);
 		g_dbus_method_invocation_return_error_literal (invocation, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
 		                                               "Already begun prompting for this prompt callback");
 		return;
@@ -813,8 +811,8 @@ on_prompt_password (GObject *source,
 	g_assert (active->ready == FALSE);
 	g_assert (active->callback != NULL);
 
-	_gcr_debug ("completed password prompt for callback %s@%s",
-	            active->callback->name, active->callback->path);
+	g_debug ("completed password prompt for callback %s@%s",
+	         active->callback->name, active->callback->path);
 
 	reply = gcr_prompt_password_finish (GCR_PROMPT (source), result, &error);
 	if (error != NULL) {
@@ -845,8 +843,8 @@ on_prompt_confirm (GObject *source,
 	g_assert (active->ready == FALSE);
 	g_assert (active->callback != NULL);
 
-	_gcr_debug ("completed confirm prompt for callback %s@%s",
-	            active->callback->name, active->callback->path);
+	g_debug ("completed confirm prompt for callback %s@%s",
+	         active->callback->name, active->callback->path);
 
 	reply = gcr_prompt_confirm_finish (GCR_PROMPT (source), result, &error);
 	if (error != NULL) {
@@ -889,20 +887,20 @@ prompter_method_perform_prompt (GcrSystemPrompter *self,
 	g_variant_get (parameters, "(&o&sa{sv}&s)",
 	               &lookup.path, &type, &iter, &received);
 
-	_gcr_debug ("received %s call from callback %s@%s",
-	            GCR_DBUS_PROMPTER_METHOD_PERFORM,
-	            lookup.path, lookup.name);
+	g_debug ("received %s call from callback %s@%s",
+	         GCR_DBUS_PROMPTER_METHOD_PERFORM,
+	         lookup.path, lookup.name);
 
 	active = g_hash_table_lookup (self->pv->active, &lookup);
 	if (active == NULL) {
-		_gcr_debug ("not begun prompting for this callback %s@%s",
-		            lookup.path, lookup.name);
+		g_debug ("not begun prompting for this callback %s@%s",
+		         lookup.path, lookup.name);
 		error = g_error_new (G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
 		                     "Not begun prompting for this prompt callback");
 
 	} else if (!active->ready) {
-		_gcr_debug ("already performing prompt for this callback %s@%s",
-		            lookup.path, lookup.name);
+		g_debug ("already performing prompt for this callback %s@%s",
+		         lookup.path, lookup.name);
 		error = g_error_new (G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
 		                     "Already performing a prompt for this prompt callback");
 	}
@@ -919,8 +917,8 @@ prompter_method_perform_prompt (GcrSystemPrompter *self,
 
 	exchange = active_prompt_get_secret_exchange (active);
 	if (!gcr_secret_exchange_receive (exchange, received)) {
-		_gcr_debug ("received invalid secret exchange from callback %s@%s",
-		            lookup.path, lookup.name);
+		g_debug ("received invalid secret exchange from callback %s@%s",
+		         lookup.path, lookup.name);
 		g_dbus_method_invocation_return_error (invocation, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS,
 		                                       "Invalid secret exchange received");
 		return;
@@ -930,21 +928,21 @@ prompter_method_perform_prompt (GcrSystemPrompter *self,
 
 	if (g_strcmp0 (type, GCR_DBUS_PROMPT_TYPE_CONFIRM) == 0) {
 		active->ready = FALSE;
-		_gcr_debug ("starting confirm prompt for callback %s@%s",
-		            lookup.path, lookup.name);
+		g_debug ("starting confirm prompt for callback %s@%s",
+		         lookup.path, lookup.name);
 		gcr_prompt_confirm_async (active->prompt, active->cancellable,
 		                          on_prompt_confirm, active_prompt_ref (active));
 
 	} else if (g_strcmp0 (type, GCR_DBUS_PROMPT_TYPE_PASSWORD) == 0) {
 		active->ready = FALSE;
-		_gcr_debug ("starting password prompt for callback %s@%s",
-		            lookup.path, lookup.name);
+		g_debug ("starting password prompt for callback %s@%s",
+		         lookup.path, lookup.name);
 		gcr_prompt_password_async (active->prompt, active->cancellable,
 		                           on_prompt_password, active_prompt_ref (active));
 
 	} else {
-		_gcr_debug ("invalid type of prompt from callback %s@%s",
-		            lookup.path, lookup.name);
+		g_debug ("invalid type of prompt from callback %s@%s",
+		         lookup.path, lookup.name);
 		g_dbus_method_invocation_return_error_literal (invocation, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS,
 		                                               "Invalid type argument");
 		return;
@@ -963,9 +961,9 @@ prompter_method_stop_prompting (GcrSystemPrompter *self,
 	lookup.name = g_dbus_method_invocation_get_sender (invocation);
 	g_variant_get (parameters, "(&o)", &lookup.path);
 
-	_gcr_debug ("received %s call from callback %s@%s",
-	            GCR_DBUS_PROMPTER_METHOD_PERFORM,
-	            lookup.path, lookup.name);
+	g_debug ("received %s call from callback %s@%s",
+	         GCR_DBUS_PROMPTER_METHOD_PERFORM,
+	         lookup.path, lookup.name);
 
 	prompt_stop_prompting (self, &lookup, TRUE, FALSE);
 
@@ -1029,7 +1027,7 @@ gcr_system_prompter_register (GcrSystemPrompter *self,
 	g_return_if_fail (self->pv->prompter_registered == 0);
 	g_return_if_fail (self->pv->connection == NULL);
 
-	_gcr_debug ("registering prompter");
+	g_debug ("registering prompter");
 
 	self->pv->connection = g_object_ref (connection);
 
@@ -1066,7 +1064,7 @@ gcr_system_prompter_unregister (GcrSystemPrompter *self,
 	g_return_if_fail (GCR_IS_SYSTEM_PROMPTER (self));
 	g_return_if_fail (self->pv->prompter_registered != 0);
 
-	_gcr_debug ("unregistering prompter");
+	g_debug ("unregistering prompter");
 
 	callbacks = g_hash_table_get_keys (self->pv->callbacks);
 	for (l = callbacks; l != NULL; l = g_list_next (l))
